@@ -22,12 +22,11 @@
 #  include <config.h>
 #endif
 
-#include <gnome.h>
 #include <glade/glade.h>
+#include <glib/gi18n.h>
 
 #include "gst.h"
-#include "gst-network-tool.h"
-#include "transfer.h"
+#include "network-tool.h"
 #include "ifaces-list.h"
 #include "callbacks.h"
 
@@ -36,12 +35,11 @@ GstTool *tool;
 static GstDialogSignal signals[] = {
   /* connections tab */
   { "properties_button",            "clicked", G_CALLBACK (on_iface_properties_clicked) },
-  { "activate_button",              "clicked", G_CALLBACK (on_activate_button_clicked) },
-  { "deactivate_button",            "clicked", G_CALLBACK (on_deactivate_button_clicked) },
   { "gateways_combo",               "changed", G_CALLBACK (on_gateway_combo_changed) },
   /* general tab */
-  { "hostname",                     "changed", G_CALLBACK (gst_dialog_modify_cb) },
-  { "domain",                       "changed", G_CALLBACK (gst_dialog_modify_cb) },
+  { "domain",                       "focus-out-event", G_CALLBACK (on_domain_focus_out) },
+  { "hostname",                     "changed", G_CALLBACK (on_entry_changed) },
+  { "domain",                       "changed", G_CALLBACK (on_entry_changed) },
   /* host aliases tab */
   { "host_aliases_add",             "clicked", G_CALLBACK (on_host_aliases_add_clicked) },
   { "host_aliases_properties",      "clicked", G_CALLBACK (on_host_aliases_properties_clicked) },
@@ -51,14 +49,12 @@ static GstDialogSignal signals[] = {
   /* connection dialog */
   { "connection_config_dialog",     "delete-event", G_CALLBACK (on_connection_dialog_close) },
   { "connection_device_active",     "clicked", G_CALLBACK (on_iface_active_changed) },
-  { "connection_ppp_device_active", "clicked", G_CALLBACK (on_iface_active_changed) },
   { "connection_bootproto",         "changed", G_CALLBACK (on_bootproto_changed) },
   { "connection_cancel",            "clicked", G_CALLBACK (on_connection_cancel_clicked) },
   { "connection_ok",                "clicked", G_CALLBACK (on_connection_ok_clicked) },
   { "connection_detect_modem",      "clicked", G_CALLBACK (on_detect_modem_clicked) },
   /* dialog changing detection */
   { "connection_address",           "focus-out-event", G_CALLBACK (on_ip_address_focus_out) },
-  { "connection_ppp_device_active", "toggled", G_CALLBACK (on_dialog_changed) },
   { "connection_device_active",     "toggled", G_CALLBACK (on_dialog_changed) },
   { "connection_essid",             "changed", G_CALLBACK (on_dialog_changed) },
   { "connection_wep_key_type",      "changed", G_CALLBACK (on_dialog_changed) },
@@ -81,15 +77,19 @@ static GstDialogSignal signals[] = {
   { NULL }
 };
 
+static GstDialogSignal signals_after[] = {
+  { "hostname",                     "focus-out-event", G_CALLBACK (on_hostname_focus_out) },
+  { NULL }
+};
+
 static void
 init_standalone_dialog (IfaceSearchTerm search_term, const gchar *term)
 {
   GstNetworkTool *network_tool;
-  GstIface       *iface;
+  OobsIface      *iface;
   GtkWidget      *d;
 
   network_tool = GST_NETWORK_TOOL (tool);
-  gst_tool_main_with_hidden_dialog (tool, TRUE);
   iface = ifaces_model_search_iface (search_term, term);
 
   if (iface)
@@ -99,7 +99,6 @@ init_standalone_dialog (IfaceSearchTerm search_term, const gchar *term)
       g_object_unref (iface);
 
       gtk_widget_show (network_tool->dialog->dialog);
-      gtk_main ();
     }
   else
     {
@@ -115,6 +114,7 @@ init_standalone_dialog (IfaceSearchTerm search_term, const gchar *term)
                                                 NULL);
       gtk_dialog_run (GTK_DIALOG (d));
       gtk_widget_destroy (d);
+      exit (-1);
     }
 }
 
@@ -159,15 +159,12 @@ main (int argc, gchar *argv[])
     { NULL }
   };
 
-  gst_init ("network-admin", argc, argv, entries);
-
+  gst_init_tool ("network-admin", argc, argv, entries);
   tool = gst_network_tool_new ();
-  gst_network_tool_construct (GST_NETWORK_TOOL (tool), "network", _("Network settings"));
 
-  gst_tool_set_xml_funcs (tool, transfer_xml_to_gui, transfer_gui_to_xml, NULL);
   gst_dialog_connect_signals (tool->main_dialog, signals);
+  gst_dialog_connect_signals_after (tool->main_dialog, signals_after);
   set_text_buffers_callback ();
-  gst_dialog_add_apply_hook (tool->main_dialog, callbacks_check_hostname_hook, NULL);
   init_filters ();
 
   if (interface)
@@ -175,7 +172,8 @@ main (int argc, gchar *argv[])
   else if (type)
     init_standalone_dialog (SEARCH_TYPE, type);
   else
-    gst_tool_main (tool, FALSE);
+    gtk_widget_show (GTK_WIDGET (tool->main_dialog));
 
+  gtk_main ();
   return 0;
 }
